| Type: | Package |
| Title: | Career Possibilities after French Selective Engineering Schools in France |
| Version: | 1.0.1 |
| Description: | To help French students from Classes Preparatoires aux Grandes Ecoles (CPGE) in their choice of field of study and career options, this package provides an interactive tool and data visualization of a graph clustered by different competitive exams and sectors of activity for French selective engineering schools and selective higher education institutions like Ecoles Normales Superieures (ENS) or specialized university programs. Besides, there are two drop-down menus to select on the graph many fields or more than 200 engineering schools or ENS. It gives the opportunity to expand, collapse clusters of selective exams interactively too. For more information, see the demonstration video: https://valerierobert-maths.re/index.php/maths-en-cpge/. The data was collected via the official French website: https://www.scei-concours.fr/statistiques.html. |
| License: | GPL (≥ 3) |
| Encoding: | UTF-8 |
| Depends: | R (≥ 3.5) |
| Imports: | dplyr, quarto, shiny, stringr, tidyr, visNetwork |
| RoxygenNote: | 7.3.3 |
| Suggests: | testthat (≥ 3.0.0) |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-07-31 18:36:49 UTC; rv |
| Author: | Valérie Robert [aut, cre] |
| Maintainer: | Valérie Robert <valerie.robert.math@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-08-08 11:20:02 UTC |
Run Shiny Interactive graph
Description
Launch the interactive Shiny graph.
Usage
data_graph()
Value
a graph clustered by different exams and sectors of activity for French selective engineering schools and selective higher education institutions like Ecoles Normales Superieures
Prepare graph data
Description
Creates the nodes, edges objects and the lists of schools, fields and selective exams required to build the interactive graph. You can select on the graph or from the drop-down menu the sector activities corresponding to chosen school for example, visualize which school belongs to a chosen group exam"
Usage
run_graph()
Value
A list containing:
- nodes
A data frame describing graph nodes.
- edges
A data frame describing graph edges.
- only_domaine
A data frame describing the different sectors of activity.
- only_ecoles
A data frame describing the different French schools.
- only_concours
A data frame describing the different French selective exams for engineering and higher education institutions.
Examples
if(interactive()){
run_graph()
}